@@ -12,8 +12,6 @@ from tornado.options import options, define
 from lesscode.utils.JsonUtil import JSONEncoder
 
 
-
-
 def Cache(ex=3600 * 8, cache_key=None):
     def cache_func(func):
         # 默认key生成方法：str(item)
@@ -70,7 +68,7 @@ def format_insert_key(func_name, args, params):
 
         str_insert_key = str_insert_key + a + "&"
     str_insert_key = str_insert_key[:-1]
-    str_insert_key = func_name + "_" + str_insert_key
+    str_insert_key = options.route_prefix + func_name + "_" + str_insert_key
 
     return str_insert_key
 
